@@ -1,4 +1,4 @@
-/* -*- Mode: C; tab-width: 8; c-basic-offset: 8; indent-tabs-mode: t; -*- */
+/* -*- Mode: C; tab-width: 8; c-basic-offset: 2; indent-tabs-mode: nil; -*- */
 
 #include "rrutil.h"
 
@@ -6,11 +6,17 @@
    where a SCHED event will stop, and the breakpoint has to fire exactly at the
    moment the SCHED event fires. So we need a SCHED event to fire at a location
    when it's the first time we've executed that location.
-   Setting the context switch time to something small-ish like -c100 should help.
+   Setting the context switch time to something small-ish like -c100 should
+   help.
    Then we generate a lot of conditional branches.
 */
 
-#define STATEMENT(i) if (a*(i) < b) { ++a; } else { ++b; }
+#define STATEMENT(i)                                                           \
+  if (a * (i) < b) {                                                           \
+    ++a;                                                                       \
+  } else {                                                                     \
+    ++b;                                                                       \
+  }
 #define STATEMENT2(i) STATEMENT(i) STATEMENT(i + 1)
 #define STATEMENT4(i) STATEMENT2(i) STATEMENT2(i + 2)
 #define STATEMENT8(i) STATEMENT4(i) STATEMENT4(i + 4)
@@ -21,10 +27,10 @@
 #define STATEMENT256(i) STATEMENT128(i) STATEMENT128(i + 128)
 
 int main(int argc, char** argv) {
-	int a = atoi(argv[1]);
-	int b = atoi(argv[2]);
-	/* This syscall signals the test that we're in the test body proper */
-	getgid();
-	STATEMENT256(0)
-	return a + b;
+  int a = atoi(argv[1]);
+  int b = atoi(argv[2]);
+  /* This syscall signals the test that we're in the test body proper */
+  getgid();
+  STATEMENT256(0)
+  return a + b;
 }
