@@ -21,6 +21,7 @@ hit_bps = { 'A': 0, 'B': 0, 'C': 0 }
 
 events = [ re.compile(r'Breakpoint 1, hit_barrier'),
            re.compile(r'Breakpoint \d, ([ABC])'),
+           re.compile(r'Remote connection closed'),
            re.compile(r'\(gdb\)') ]
 while 1:
     send_gdb('s\n')
@@ -28,6 +29,8 @@ while 1:
     if 0 == i:
         break
     if 2 == i:
+        assert False, 'Program stopped unexpectedly, review gdb_rr.log'
+    if 3 == i:
         continue
 
     bp = last_match().group(1)
@@ -38,9 +41,19 @@ while 1:
 for bp in hit_bps.iterkeys():
     assert hit_bps[bp]
 
+arch = get_exe_arch()
+
+# The locations the threads are stopped at depends on the architecture.
+stopped_locations = {
+    'i386': ['(0x[0-9a-f]+ in )?__kernel_vsyscall', '(0x[0-9a-f]+ in )?_traced_raw_syscall', '0x70000010 in \?\?'],
+    'i386:x86-64': ['(0x[0-9a-f]+ in )?__lll_lock_wait', '(0x[0-9a-f]+ in )?pthread_barrier_wait', '0x70000010 in \?\?'],
+}
+
+location_regex = '|'.join(stopped_locations[arch])
+
 send_gdb('info threads\n')
-expect_gdb(r'3\s+Thread.+?(?:_traced_raw_syscall|__kernel_vsyscall)')
-expect_gdb(r'2\s+Thread.+?(?:_traced_raw_syscall|__kernel_vsyscall)')
+expect_gdb(r'3\s+Thread.+?(?:%s)' % location_regex)
+expect_gdb(r'2\s+Thread.+?(?:%s)' % location_regex)
 expect_gdb(r'1\s+Thread.+hit_barrier')
 
 ok()
